@@ -14,7 +14,7 @@ class WristRoll(DynamixelHelloXL430):
         """
         Home to hardstops
         """
-        self.pose('forward')
+        pass
 
     def pose(self,p,v_r=None,a_r=None):
         """
